@@ -23,10 +23,10 @@ import java.util.Map;
  */
 public class ResUnknownFiles {
 
-    private final Map<String, String> mUnknownFiles = new LinkedHashMap<String, String>();
+    private final Map<String, String> mUnknownFiles = new LinkedHashMap<>();
 
     public void addUnknownFileInfo(String file, String value) {
-        mUnknownFiles.put(file,value);
+        mUnknownFiles.put(file, value);
     }
 
     public Map<String, String> getUnknownFiles() {
