@@ -34,11 +34,13 @@ public class ResFileValue extends ResIntBasedValue {
     }
 
     public String getStrippedPath() throws AndrolibException {
-        if (!mPath.startsWith("res/")) {
-            throw new AndrolibException(
-                    "File path does not start with \"res/\": " + mPath);
+        if (mPath.startsWith("res/")) {
+            return mPath.substring(4);
         }
-        return mPath.substring(4);
+        if (mPath.startsWith("r/") || mPath.startsWith("R/")) {
+            return mPath.substring(2);
+        }
+        throw new AndrolibException("File path does not start with \"res/\" or \"r/\": " + mPath);
     }
 
     @Override
