@@ -154,6 +154,12 @@ public class ARSCDecoder {
 
         while (type == Header.TYPE_TYPE) {
             readTableType();
+            
+            // skip "TYPE 8 chunks" and/or padding data at the end of this chunk
+            if(mCountIn.getCount() < mHeader.endPosition) {
+                mCountIn.skip(mHeader.endPosition - mCountIn.getCount());
+            }
+            
             type = nextChunk().type;
 
             addMissingResSpecs();
@@ -375,6 +381,11 @@ public class ARSCDecoder {
             read = 52;
         }
 
+        if (size >= 56) {
+            mIn.skipBytes(4);
+            read = 56;
+        }
+
         int exceedingSize = size - KNOWN_CONFIG_BYTES;
         if (exceedingSize > 0) {
             byte[] buf = new byte[exceedingSize];
@@ -550,7 +561,7 @@ public class ARSCDecoder {
     }
 
     private static final Logger LOGGER = Logger.getLogger(ARSCDecoder.class.getName());
-    private static final int KNOWN_CONFIG_BYTES = 52;
+    private static final int KNOWN_CONFIG_BYTES = 56;
 
     public static class ARSCData {
 
